/*
 * closedir.c - Close a directory stream.
 *
 * This file is part of the Portable.NET C library.
 * Copyright (C) 2003  Free Software Foundation, Inc.
 * Copyright (C) 2004  Southern Storm Software, Pty Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <errno.h>
#include <stddef.h>
#include <stdlib.h>
#include <dirent.h>
#include "dirent-glue.h"

int
__closedir (DIR *dirp)
{
  int err;

  if (dirp == NULL || dirp->gc_handle == NULL)
    {
      errno = EBADF;
      return -1;
    }

  err = 0;
  __syscall_closedir (dirp->gc_handle, &err);

  if (err)
    {
      errno = err;
      return -1;
    }

  free (dirp);
  return 0;
}
weak_alias (__closedir, closedir)
